summaryrefslogtreecommitdiffstats
path: root/kbruch/src/kbruch.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbruch/src/kbruch.cpp')
-rw-r--r--kbruch/src/kbruch.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbruch/src/kbruch.cpp b/kbruch/src/kbruch.cpp
index df74101e..aaca2b02 100644
--- a/kbruch/src/kbruch.cpp
+++ b/kbruch/src/kbruch.cpp
@@ -23,7 +23,7 @@
#include <time.h>
#include <stdlib.h>
/* these includes are needed for Qt support */
#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
@@ -48,10 +48,10 @@ int main(int argc, char * argv[])
KApplication kbruch;
- MainQtWidget * kbruchApp = new MainQtWidget();
+ MainTQtWidget * kbruchApp = new MainTQtWidget();
kbruch.setMainWidget(kbruchApp);
kbruchApp->show();
/* lets execute the Qt GUI; it will handle all cmd options which are left */
return kbruch.exec();
}
@@ -23,7 +23,7 @@
#include <time.h>
#include <stdlib.h>
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <kapplication.h>
#include <kcmdlineargs.h>
@@ -48,10 +48,10 @@ int main(int argc, char * argv[])
kbruch.setMainWidget(kbruchApp);
kbruchApp->show();
- /* lets execute the Qt GUI; it will handle all cmd options which are left */
+ /* lets execute the TQt GUI; it will handle all cmd options which are left */
return kbruch.exec();
}